/***************************************************************************
 * Copyright 2001-2005 The eXo Platform SARL         All rights reserved.  *
 * Please look at license.txt in info directory for more license detail.   *
 **************************************************************************/
package suites.ecm.admin;

import condition.* ;
import suites.share.CommonUnit ;
import suites.share.UserLoginSuite;

import org.exoplatform.test.web.*;
import org.exoplatform.test.web.unit.*;
import org.exoplatform.test.web.validator.*;
import suites.share.UserLogoutSuite;

/**
 * this suite does: 
 *  1)Go to Manage Taxonomy on Admin the ECM tab 
 *  2)Add a new category on  exo:taxonomies which has name is newCategory  
 *  3)Readd newCategory on exo:taxonomies
 *  4)Add a new category on newCategory which has name is childCategory
 *  5)Delete  childCategory
 *  6)Readd childCategory 
 *  
 * Created by The eXo Platform SARL
 * Author : Hoa Nguyen Thi
 *          hoa2501@yahoo.com
 * Apr 5, 2005
 */
public class AdminManageTaxonomySuite extends WebUnitSuite {
  static String DESC = "Go to Manager Taxonomy and test all basic actions" ;
  static String NAME = "AdminManageTaxonomySuite" ;
  String COMMENT = null;   
  public AdminManageTaxonomySuite() {    
    super(NAME, DESC) ;     
    goToPage("/Home/ecm") ;
    //Click Admin The ECM
    addWebUnit(
      new ClickURLLinkUnit("SelectAdminTheECM", "Select Admin The ECM tab").
      setURL("componentId=ECMPage&portal:action=changeTab&objectId=ecm").                  
      addValidator(new ExpectLinkWithURLValidator("uicomponent=UIECMAdminSummary&op=manageTaxonomy"))      
    ) ;      
    //Click on Manager Taxonomy icon
    addWebUnit(
      new ClickURLLinkUnit("ClickManagerTaxonomy", "Click on Manage Metadata icon").
      setURL("uicomponent=UIECMAdminSummary&op=manageTaxonomy").                  
      addValidator(new ExpectLinkWithURLValidator("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies"))      
    ) ;
    //-----Delete if existed newCategory on exo:taxonomies
    addWebUnit(
        new ClickURLLinkUnit("DeleteExistednewCategory", "Delete if existed newCategory on exo:taxonomies").
        setURL("uicomponent=UITaxonomyManager&op=removeTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory"). 
        addCondition(new HaveLinkWithURLCondition("uicomponent=UITaxonomyManager&op=removeTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory")).
        addValidator(new ExpectNoTextValidator("newCategory"))      
    ) ;
    //-----Add new category
    addWebUnit(
        new ClickURLLinkUnit("AddNewCategory", "Click on add icon of exo:taxonomies ").
        setURL("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies").                  
        addValidator(new ExpectFormIdValidator("taxonomyForm"))      
    ) ;        
    addWebUnit(
        new SubmitFormUnit("CreateNewCategory", "Create a new category on exo:taxonomies").
        setFormId("taxonomyForm").
        setField("name","newCategory").
        setField("op","save").       
        addValidator(new ExpectTextValidator("newCategory")).         
        addValidator(new ExpectLinkWithURLValidator("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory"))
    ) ;
    //-----Readd new category
    addWebUnit(
        new ClickURLLinkUnit("ReAddNewCategory", "Click on add icon of exo:taxonomies ").
        setURL("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies").                  
        addValidator(new ExpectFormIdValidator("taxonomyForm"))      
    ) ;
    addWebUnit(
        new SubmitFormUnit("ReCreateNewCategory", "Create a new category on exo:taxonomies").
        setFormId("taxonomyForm").
        setField("name","newCategory").
        setField("op","save").       
        addValidator(new ExpectTextValidator("The item already exists."))        
    ) ;
    addWebUnit(
        new SubmitFormUnit("ClickOnCancel", "Click on cancel icon").
        setFormId("taxonomyForm").
        setField("op","PhaseId[1].cancel").       
        addValidator(new ExpectTextValidator("newCategory"))        
    ) ;
    //-----Delete if existed childCategory on newCategory
    addWebUnit(
        new ClickURLLinkUnit("DeleteExistedchildCategory", "Delete if existed childCategory on newCategory").
        setURL("uicomponent=UITaxonomyManager&op=removeTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory/childCategory"). 
        addCondition(new HaveLinkWithURLCondition("uicomponent=UITaxonomyManager&op=removeTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory/childCategory")).
        addValidator(new ExpectNoTextValidator("childCategory"))      
    ) ;
    //-----Add child category of newCategory
    addWebUnit(
        new ClickURLLinkUnit("AddChildCategory", "Click on add icon of exo:taxonomies ").
        setURL("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory").                  
        addValidator(new ExpectFormIdValidator("taxonomyForm"))      
    ) ;
    addWebUnit(
        new SubmitFormUnit("CreateChildCategory", "Create a child category on newCategory").
        setFormId("taxonomyForm").
        setField("name","childCategory").
        setField("op","save").       
        addValidator(new ExpectTextValidator("childCategory")).         
        addValidator(new ExpectLinkWithURLValidator("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory/childCategory"))
    ) ;
    //-----Delete childCategory
    addWebUnit(
        new ClickURLLinkUnit("DeleteChildCategory", "Click on delete icon of childCategory").
        setURL("uicomponent=UITaxonomyManager&op=removeTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory/childCategory").                  
        addValidator(new ExpectNoTextValidator("childCategory"))            
    ) ;
    COMMENT = "Copy can not yet action";
    addWebUnit(
      new TODO("Can'tCopyCategory", COMMENT).
      setComment(COMMENT).
      setStatus(WebUnit.STATUS_INCOMPLETE)
    ) ;
    COMMENT = "Parse can not yet action";
    addWebUnit(
      new TODO("Can'tParseCategory", COMMENT).
      setComment(COMMENT).
      setStatus(WebUnit.STATUS_INCOMPLETE)
    ) ;
    COMMENT = "Cut can not yet action";
    addWebUnit(
      new TODO("Can'tCutCategory", COMMENT).
      setComment(COMMENT).
      setStatus(WebUnit.STATUS_INCOMPLETE)
    ) ;    
    //-----Re add child category of newCategory
    addWebUnit(
        new ClickURLLinkUnit("AddChildCategory", "Click on add icon of exo:taxonomies ").
        setURL("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory").                  
        addValidator(new ExpectFormIdValidator("taxonomyForm"))      
    ) ;
    addWebUnit(
        new SubmitFormUnit("CreateChildCategory", "Create a child category on newCategory").
        setFormId("taxonomyForm").
        setField("name","childCategory").
        setField("op","save").       
        addValidator(new ExpectTextValidator("childCategory")).         
        addValidator(new ExpectLinkWithURLValidator("uicomponent=UITaxonomyManager&op=addTaxonomy&objectId=/jcr:system/exo:ecm/exo:taxonomies/newCategory/childCategory"))
    ) ;
    addWebUnit(
        new ClickURLLinkUnit("GoBackWorkspace", "Go back workspace ").
        setURL("uicomponent=UITaxonomyManager&op=PhaseId[1].cancel").                  
        addValidator(new ExpectLinkWithURLValidator("uicomponent=UIECMAdminSummary&op=manageMetadata"))      
    ) ;
  }                 
  public java.util.List getRequiredSuites() { 
    String[] roles = ["user", "admin"] ;
    return [new UserLoginSuite(CommonUnit.NAME_EXO_ADMIN, "exo", roles)] ;
  }  
}